@@ -215,7 +215,8 @@ class LoggingConfManager:
         self.loggers.empty()
         self.mapping = {}
         self.handlers.empty()
-
+        if self.online_handler:
+            self.online_handler.clear()
         self._collect_handlers()
         self._inspect()
         self.create_mapping()
@@ -237,7 +238,7 @@ class LoggingConfManager:
             lgr.setLevel(kwargs["level"])
             actions.append(f"{logger_name}: setting level {kwargs['level']}")
         selected_handlers = kwargs.get("handlers", [])
-        if kwargs.get("inspect", True):
+        if kwargs.get("inspect", False):
             selected_handlers.append(conf.ONLINE_LOGGER_NAME)
         if not selected_handlers:
             lgr.handlers.clear()
