@@ -1,3 +1,4 @@
+import os
 import socket
 import types
 from functools import lru_cache
@@ -6,6 +7,11 @@ from inspect import isclass
 import redis
 
 
+@lru_cache(None)
+def get_signature() -> str:
+    return str(os.getpid())
+
+
 @lru_cache(None)
 def get_redis_connection() -> redis.client.Redis:
     from . import conf
